@@ -23,7 +23,11 @@ def sort_out_all_vm(self: "PyMemuc") -> bool:
 
 # TODO: look into bindings with https://github.com/egirault/googleplay-api
 def install_apk_vm(
-    self: "PyMemuc", apk_path, vm_index=None, vm_name=None, create_shortcut=False
+    self: "PyMemuc",
+    apk_path,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
+    create_shortcut=False,
 ) -> Literal[True]:
     """Install an APK on a VM, must specify either a vm index or a vm name
 
@@ -68,7 +72,10 @@ def install_apk_vm(
 
 
 def uninstall_apk_vm(
-    self: "PyMemuc", package_name, vm_index=None, vm_name=None
+    self: "PyMemuc",
+    package_name,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
 ) -> Literal[True]:
     """Uninstall an APK on a VM, must specify either a vm index or a vm name
 
@@ -97,7 +104,10 @@ def uninstall_apk_vm(
 
 
 def start_app_vm(
-    self: "PyMemuc", package_name, vm_index=None, vm_name=None
+    self: "PyMemuc",
+    package_name,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
 ) -> Literal[True]:
     """Start an app on a VM, must specify either a vm index or a vm name
 
@@ -124,7 +134,10 @@ def start_app_vm(
 
 
 def stop_app_vm(
-    self: "PyMemuc", package_name, vm_index=None, vm_name=None
+    self: "PyMemuc",
+    package_name,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
 ) -> Literal[True]:
     """Stop an app on a VM, must specify either a vm index or a vm name
 
@@ -153,8 +166,8 @@ def stop_app_vm(
 def trigger_keystroke_vm(
     self: "PyMemuc",
     key: Literal["back", "home", "menu", "volumeup", "volumedown"],
-    vm_index=None,
-    vm_name=None,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
 ) -> Literal[True]:
     """Trigger a keystroke on a VM, must specify either a vm index or a vm name
 
@@ -180,7 +193,9 @@ def trigger_keystroke_vm(
     return True
 
 
-def trigger_shake_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
+def trigger_shake_vm(
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None
+) -> Literal[True]:
     """Trigger a shake on a VM, must specify either a vm index or a vm name
 
     :param vm_index: VM index. Defaults to None.
@@ -203,7 +218,9 @@ def trigger_shake_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[Tr
     return True
 
 
-def connect_internet_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
+def connect_internet_vm(
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None
+) -> Literal[True]:
     """Connect the internet on a VM, must specify either a vm index or a vm name
 
     :param vm_index: VM index. Defaults to None.
@@ -227,7 +244,7 @@ def connect_internet_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal
 
 
 def disconnect_internet_vm(
-    self: "PyMemuc", vm_index=None, vm_name=None
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None
 ) -> Literal[True]:
     """Disconnect the internet on a VM, must specify either a vm index or a vm name
 
@@ -251,7 +268,9 @@ def disconnect_internet_vm(
     return True
 
 
-def input_text_vm(self: "PyMemuc", text, vm_index=None, vm_name=None) -> Literal[True]:
+def input_text_vm(
+    self: "PyMemuc", text, vm_index: int | None = None, vm_name: str | None = None
+) -> Literal[True]:
     """Input text on a VM, must specify either a vm index or a vm name
 
     :param text: Text to input
@@ -276,7 +295,9 @@ def input_text_vm(self: "PyMemuc", text, vm_index=None, vm_name=None) -> Literal
     return True
 
 
-def rotate_window_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
+def rotate_window_vm(
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None
+) -> Literal[True]:
     """Rotate the window on a VM, must specify either a vm index or a vm name
 
     :param vm_index: VM index. Defaults to None.
@@ -298,7 +319,7 @@ def rotate_window_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[Tr
 
 
 def execute_command_vm(
-    self: "PyMemuc", command, vm_index=None, vm_name=None
+    self: "PyMemuc", command, vm_index: int | None = None, vm_name: str | None = None
 ) -> tuple[int, str]:
     """Execute a command on a VM, must specify either a vm index or a vm name
 
@@ -320,7 +341,11 @@ def execute_command_vm(
 
 
 def change_gps_vm(
-    self: "PyMemuc", latitude: float, longitude: float, vm_index=None, vm_name=None
+    self: "PyMemuc",
+    latitude: float,
+    longitude: float,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
 ) -> Literal[True]:
     """Change the GPS location on a VM, must specify either a vm index or a vm name
 
@@ -353,7 +378,9 @@ def change_gps_vm(
 
 
 # TODO: fix parsing of the output
-def get_public_ip_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> tuple[int, str]:
+def get_public_ip_vm(
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None
+) -> tuple[int, str]:
     """Get the public IP of a VM, must specify either a vm index or a vm name
 
     :param vm_index: VM index. Defaults to None.
@@ -375,7 +402,9 @@ def get_public_ip_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> tuple[int,
     raise PyMemucIndexError("Please specify either a vm index or a vm name")
 
 
-def zoom_in_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
+def zoom_in_vm(
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None
+) -> Literal[True]:
     """Zoom in on a VM, must specify either a vm index or a vm name
 
     :param vm_index: VM index. Defaults to None.
@@ -398,7 +427,9 @@ def zoom_in_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
     return True
 
 
-def zoom_out_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
+def zoom_out_vm(
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None
+) -> Literal[True]:
     """Zoom out on a VM, must specify either a vm index or a vm name
 
     :param vm_index: VM index. Defaults to None.
@@ -422,7 +453,7 @@ def zoom_out_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
 
 
 def get_app_info_list_vm(
-    self: "PyMemuc", vm_index=None, vm_name=None, timeout=10
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None, timeout=10
 ) -> list[str]:
     """Get the list of apps installed on a VM, must specify either a vm index or a vm name
 
@@ -462,8 +493,8 @@ def get_app_info_list_vm(
 def set_accelerometer_vm(
     self: "PyMemuc",
     value: tuple[float, float, float],
-    vm_index=None,
-    vm_name=None,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
 ) -> tuple[int, str]:
     """Set the accelerometer on a VM, must specify either a vm index or a vm name
 
@@ -506,8 +537,8 @@ def set_accelerometer_vm(
 def create_app_shortcut_vm(
     self: "PyMemuc",
     package_name: str,
-    vm_index=None,
-    vm_name=None,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
 ) -> tuple[int, str]:
     """Create an app shortcut on a VM, must specify either a vm index or a vm name
 
@@ -539,7 +570,7 @@ def create_app_shortcut_vm(
 
 # TODO: parse the output
 def send_adb_command_vm(
-    self: "PyMemuc", command, vm_index=None, vm_name=None
+    self: "PyMemuc", command, vm_index: int | None = None, vm_name: str | None = None
 ) -> tuple[int, str]:
     """Send an ADB command to a VM, must specify either a vm index or a vm name
 
