@@ -2,7 +2,8 @@
 from contextlib import suppress
 from os.path import join, normpath
 from subprocess import PIPE, CalledProcessError, Popen, TimeoutExpired
-from tempfile import NamedTemporaryFile
+from tempfile import TemporaryFile
+from typing import TYPE_CHECKING
 
 from ._constants import WIN32, WINREG_EN
 from .exceptions import PyMemucError, PyMemucException, PyMemucTimeoutExpired
@@ -19,6 +20,9 @@ if WIN32:
 else:
     ST_INFO = None
 
+if TYPE_CHECKING:
+    from pymemuc import PyMemuc
+
 
 @staticmethod
 def _get_memu_top_level() -> str:
@@ -41,11 +45,12 @@ def _get_memu_top_level() -> str:
 
 
 def memuc_run(
-    self, args: list[str], non_blocking=False, timeout=None
+    self: "PyMemuc", args: list[str], non_blocking=False, timeout=None
 ) -> tuple[int, str]:
     """run a command with memuc.exe.
     Memuc can support non-blocking commands, returning a task id.
-    A timeout can be specified if memuc is expected to hang, but this will not work with non-blocking commands.
+    A timeout can be specified if memuc is expected to hang,
+    but this will not work with non-blocking commands.
 
     :param args: a list of arguments to pass to memuc.exe
     :type args: list[str]
@@ -68,7 +73,7 @@ def memuc_run(
         print("pymemuc._memuc.memuc_run:")
         print(f"\tCommand: {' '.join(args)}")
     try:
-        with NamedTemporaryFile(mode="r+", delete=False) as stdout_file:
+        with TemporaryFile(mode="r+") as stdout_file:
             with Popen(
                 args,
                 stdin=PIPE,
@@ -87,14 +92,17 @@ def memuc_run(
                 stdout_file.seek(0)
                 result = stdout_file.read()
                 if self.debug:
-                    print(f"\tOutput: {result}")
+                    if lines := result.splitlines():
+                        print(f"\tOutput: {lines.pop(0)}")
+                        for line in lines:
+                            print(f"\t\t{line}")
                 return (0, result)
     except CalledProcessError as err:
         raise PyMemucError(err) from err
 
 
 # TODO: add output parsing
-def check_task_status(self, task_id: str) -> tuple[int, str]:
+def check_task_status(self: "PyMemuc", task_id: str) -> tuple[int, str]:
     """Check the status of a task
 
     :param task_id: Asynchronous task ID
